@@ -38,22 +38,19 @@ class CPWordEncoding(MIDITokenizer):
             The values are the resolution, in samples per beat, of the given range, ex 8
     :param nb_velocities: number of velocity bins
     :param additional_tokens: specifies additional tokens (chords, time signature, rests, tempo...)
-    :param program_tokens: will add entries for MIDI programs in the dictionary, to use
-            in the case of multitrack generation for instance
-    :param sos_eos_tokens: Adds Start Of Sequence (SOS) and End Of Sequence (EOS) tokens to the vocabulary
+    :param sos_eos_tokens: adds Start Of Sequence (SOS) and End Of Sequence (EOS) tokens to the vocabulary
     :param params: can be a path to the parameter (json encoded) file or a dictionary
     """
 
     def __init__(self, pitch_range: range = PITCH_RANGE, beat_res: Dict[Tuple[int, int], int] = BEAT_RES,
                  nb_velocities: int = NB_VELOCITIES, additional_tokens: Dict[str, bool] = ADDITIONAL_TOKENS,
-                 program_tokens: bool = PROGRAM_TOKENS, sos_eos_tokens: bool = False, params=None):
+                 sos_eos_tokens: bool = False, params=None):
         # Indexes of additional token types within a compound token
         self.chord_idx = -3 if additional_tokens['Tempo'] and additional_tokens['Rest'] else -2 if \
             additional_tokens['Tempo'] or additional_tokens['Rest'] else -1
         self.rest_idx = -2 if additional_tokens['Tempo'] else -1
         self.tempo_idx = -1
-        super().__init__(pitch_range, beat_res, nb_velocities, additional_tokens,
-                         {'program_tokens': program_tokens, 'sos_eos_tokens': sos_eos_tokens}, params)
+        super().__init__(pitch_range, beat_res, nb_velocities, additional_tokens, sos_eos_tokens, params)
 
     def track_to_tokens(self, track: Instrument) -> List[List[int]]:
         """ Converts a track (miditoolkit.Instrument object) into a sequence of tokens
@@ -264,12 +261,11 @@ class CPWordEncoding(MIDITokenizer):
         tempo_changes[0].time = 0
         return instrument, tempo_changes
 
-    def _create_vocabulary(self, program_tokens: bool, sos_eos_tokens: bool = False) -> Vocabulary:
+    def _create_vocabulary(self, sos_eos_tokens: bool = False) -> Vocabulary:
         """ Creates the Vocabulary object of the tokenizer.
         See the docstring of the Vocabulary class for more details about how to use it.
         NOTE: token index 0 is often used as a padding index during training
 
-        :param program_tokens: will include tokens for MIDI programs
         :param sos_eos_tokens: will include Start Of Sequence (SOS) and End Of Sequence (tokens)
         :return: the vocabulary object
         """
@@ -309,7 +305,7 @@ class CPWordEncoding(MIDITokenizer):
             vocab.add_event(f'Tempo_{i}' for i in self.tempos)
 
         # PROGRAM
-        if program_tokens:
+        if self.additional_tokens['Program']:
             vocab.add_event('Family_Program')
             vocab.add_event(f'Program_{program}' for program in range(-1, 128))
 
@@ -319,21 +315,21 @@ class CPWordEncoding(MIDITokenizer):
 
         return vocab
 
-    def create_token_types_graph(self) -> Dict[str, List[str]]:
-        """ As with CP the tokens types are "merged", each state here corresponds to
+    def _create_token_types_graph(self) -> Dict[str, List[str]]:
+        """ Returns a graph (as a dictionary) of the possible token
+        types successions.
+        As with CP the tokens types are "merged", each state here corresponds to
         a "compound" token, which is characterized by the token types Program, Bar,
         Position/Chord/Tempo and Pitch/Velocity/Duration
+        Here the combination of Pitch, Velocity and Duration tokens is represented by
+        "Pitch" in the graph.
+        NOTE: Program type is not referenced here, you can add it manually by
+        modifying the tokens_types_graph class attribute following your strategy.
 
         :return: the token types transitions dictionary
         """
         dic = dict()
 
-        try:
-            _ = self.vocab.tokens_of_type('Program')
-            dic['Program'] = ['Bar']
-        except KeyError:
-            pass
-
         dic['Bar'] = ['Position']
         dic['Position'] = ['Pitch']
         dic['Pitch'] = ['Pitch', 'Bar', 'Position']
