@@ -28,12 +28,12 @@ class MIDITokenizer:
             The values are the resolution, in samples per beat, of the given range, ex 8
     :param nb_velocities: number of velocity bins
     :param additional_tokens: specifies additional tokens (chords, rests, tempo...)
-    :param vocab_args: arguments for the _create_vocabulary method
+    :param sos_eos_tokens: adds Start Of Sequence (SOS) and End Of Sequence (EOS) tokens to the vocabulary
     :param params: can be a path to the parameter (json encoded) file or a dictionary
     """
 
     def __init__(self, pitch_range: range, beat_res: Dict[Tuple[int, int], int], nb_velocities: int,
-                 additional_tokens: Dict[str, Union[bool, int, Tuple[int, int]]], vocab_args: Dict[str, any],
+                 additional_tokens: Dict[str, Union[bool, int, Tuple[int, int]]], sos_eos_tokens: bool = False,
                  params: Union[str, Path, PurePath, Dict[str, Any]] = None):
         # Initialize params
         if params is None:
@@ -67,8 +67,9 @@ class MIDITokenizer:
                 'The minimum rest value must be equal or superior to the initial beat resolution'
             self.rests = self.__create_rests()
 
-        # Vocabulary
-        self.vocab = self._create_vocabulary(**vocab_args)
+        # Vocabulary and token types graph
+        self.vocab = self._create_vocabulary(sos_eos_tokens)
+        self.tokens_types_graph = self._create_token_types_graph()
 
         # Keep in memory durations in ticks for seen time divisions so these values
         # are not calculated each time a MIDI is processed
@@ -301,8 +302,9 @@ class MIDITokenizer:
         """
         raise NotImplementedError
 
-    def create_token_types_graph(self) -> Dict[str, List[str]]:
-        """ Creates a dictionary for the directions of the token types of the encoding"""
+    def _create_token_types_graph(self) -> Dict[str, List[str]]:
+        """ Creates a dictionary for the directions of the token types of the encoding
+        See other classes (RemiEncoding, MIDILikeEncoding ...) for examples of how to implement it."""
         raise NotImplementedError
 
     def __create_durations_tuples(self) -> List[Tuple]:
@@ -368,7 +370,7 @@ class MIDITokenizer:
 
         for m, midi_path in enumerate(midi_paths):
             if logging:
-                bar_len = 60
+                bar_len = 30
                 filled_len = int(round(bar_len * m / len(midi_paths)))
                 percents = round(100.0 * m / len(midi_paths), 2)
                 bar = '=' * filled_len + '-' * (bar_len - filled_len)
@@ -399,7 +401,7 @@ class MIDITokenizer:
         self.save_params(out_dir)  # Saves the parameters with which the MIDIs are converted
 
     @staticmethod
-    def save_tokens(tokens, path: Union[str, Path, PurePath], programs=None):
+    def save_tokens(tokens, path: Union[str, Path, PurePath], programs: List[Tuple[int, bool]] = None):
         """ Saves tokens as a JSON file.
 
         :param tokens: tokens, as any format
